==> cdk_2.3.orig.tar.gz: cdk-cdk-2.3/storage/ioformats/src/test/java/org/openscience/cdk/io/formats/MOPAC97FormatTest.java <==
/* Copyright (C) 2008  Egon Willighagen <egonw@users.sf.net>
 *
 * Contact: cdk-devel@slists.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 * All we ask is that proper credit is given for our work, which includes
 * - but is not limited to - adding the above copyright notice to the beginning
 * of your source code files, and to any copyright notice that you may distribute
 * with programs based on this work.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 */
package org.openscience.cdk.io.formats;

import org.junit.Assert;
import org.junit.Test;

/**
 * @cdk.module test-ioformats
 */
public class MOPAC97FormatTest extends ChemFormatMatcherTest {

    public MOPAC97FormatTest() {
        super.setChemFormatMatcher((IChemFormatMatcher) MOPAC97Format.getInstance());
    }

    @Test
    public void testMatchesMopac97() throws Exception {
        Assert.assertTrue(((MOPAC97Format) MOPAC97Format.getInstance()).matches(0, "MOPAC  97.00"));
    }
}

==> cdk_2.8.orig.tar.gz: cdk-cdk-2.8/storage/ioformats/src/test/java/org/openscience/cdk/io/formats/MOPAC97FormatTest.java <==
/* Copyright (C) 2008  Egon Willighagen <egonw@users.sf.net>
 *
 * Contact: cdk-devel@slists.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 * All we ask is that proper credit is given for our work, which includes
 * - but is not limited to - adding the above copyright notice to the beginning
 * of your source code files, and to any copyright notice that you may distribute
 * with programs based on this work.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 */
package org.openscience.cdk.io.formats;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

/**
 * @cdk.module test-ioformats
 */
class MOPAC97FormatTest extends ChemFormatMatcherTest {

    MOPAC97FormatTest() {
        super.setChemFormatMatcher((IChemFormatMatcher) MOPAC97Format.getInstance());
    }

    @Test
    void testMatchesMopac97() throws Exception {
        Assertions.assertTrue(((MOPAC97Format) MOPAC97Format.getInstance()).matches(0, "MOPAC  97.00"));
    }
}
